@@ -5,7 +5,6 @@ Dataset manipulation functions
 Author: Alex Sobral de Freitas
 """
 
-from math import e
 import os
 import json
 import random
@@ -72,7 +71,11 @@ class Dataset():
             self.db_config = CONFIG["db-service"]
 
         self._cloud_parms = cloud_parms
-        self._file_ac = FileAccess(storage="dataset", resource_id=self.id, cloud_parms=self._cloud_parms)
+        self._file_ac = FileAccess(
+            storage="dataset",
+            resource_id=self.id,
+            cloud_parms=self._cloud_parms
+        )
 
         self.parms = {}
         self.examples = []
@@ -114,7 +117,6 @@ class Dataset():
             for exp in cursor:
                 self.examples.append(exp)
 
-        # self.load_images_from_disk()
         log.info(f"Load dataset from database {len(self.examples)} examples")
 
 
@@ -122,7 +124,6 @@ class Dataset():
         """
         Load images from disk
         """
-        # file_ac = FileAccess(storage="dataset", resource_id=self.id, cloud_parms=self._cloud_parms)
         if self._cloud_parms is not None:
             self._file_ac.sync_files(origin=origin)
 
@@ -135,8 +136,6 @@ class Dataset():
         """
         Load images in memory
         """
-        # file_ac = FileAccess(storage="dataset", resource_id=self.id, cloud_parms=self._cloud_parms)
-
         for exp in self.examples:
             if exp["example"] in self.images:
                 continue
@@ -207,8 +206,6 @@ class Dataset():
         """
         self.load_all_images()
 
-        # file_ac = FileAccess(storage="dataset", resource_id=self.id, cloud_parms=self._cloud_parms)
-
         for exp in self.examples:
             if self._file_ac.is_file(exp["example"]):
                 self._file_ac.remove_file(exp["example"])
@@ -232,35 +229,29 @@ class Dataset():
 
 
         if example_img not in self.images:
-            # raise Exception(f'Example {example_img} not found')
             self.images[example_img] = load_file_from_cloud(example_img)
 
         return cv2.imdecode(np.frombuffer(self.images[example_img], dtype=np.uint8), cv2.IMREAD_COLOR)
 
 
-    def get_train_subsets(self):
+    def get_train_subsets(self, shuffle=True):
         """
         Partitioning of dataset in 3 groups: train, validation and test
         """
         if not self.parms:
             raise Exception('Must load or import dataset first')
 
-        train_dataset = Dataset(self.id)
-        train_dataset.db_config = self.db_config
-        train_dataset._cloud_parms = self._cloud_parms
+        train_dataset = Dataset(self.id, db_config=self.db_config, cloud_parms=self._cloud_parms)
         train_dataset.parms = copy.deepcopy(self.parms)
 
-        val_dataset = Dataset(self.id)
-        val_dataset.db_config = self.db_config
-        val_dataset._cloud_parms = self._cloud_parms
+        val_dataset = Dataset(self.id, db_config=self.db_config, cloud_parms=self._cloud_parms)
         val_dataset.parms = copy.deepcopy(self.parms)
 
-        test_dataset = Dataset(self.id)
-        test_dataset.db_config = self.db_config
-        test_dataset._cloud_parms = self._cloud_parms
+        test_dataset = Dataset(self.id, db_config=self.db_config, cloud_parms=self._cloud_parms)
         test_dataset.parms = copy.deepcopy(self.parms)
 
-        random.shuffle(self.examples)
+        if shuffle:
+            random.shuffle(self.examples)
 
         val_size = int(len(self.examples) * self.parms["network_parms"]["val_size"])
         if val_size < 1:
